@@ -8,8 +8,10 @@ __doc__ = r"""
            Created on 9/14/19
            """
 
+from _pytest.capture import CaptureFixture
 
-def test_print(capsys):
+
+def test_print(capsys: CaptureFixture[str]) -> None:
     """Correct my_name argument prints"""
     text = "hello"
     err = "world"
@@ -18,3 +20,7 @@ def test_print(capsys):
     captured = capsys.readouterr()
     assert text in captured.out
     assert err in captured.err
+
+
+if __name__ == "__main__":
+    test_print()
