@@ -14,14 +14,19 @@ __all__ = [
     "ensure_in_sys_path",
     "clean_sys_path",
     "import_file",
+    "find_ancestral_relatives",
+    "find_nearest_ancestral_relative",
+    "walk_up",
 ]
 
 import sys
 from importlib.util import find_spec
 from pathlib import Path
-from typing import Optional, Any, Union
+from typing import Optional, Any, Union, List
 from warnings import warn
 
+from warg import passes_kws_to
+
 
 def import_file(path: Path, from_list=None) -> Any:
     """Import a module given its filename, works both on absolute and relative paths"""
@@ -40,6 +45,86 @@ def import_file(path: Path, from_list=None) -> Any:
         sys.path = sys_path  # Restore original sys.path
 
 
+def walk_up(path: Path, top: Path, max_ascent: int = None):
+    i = 0
+    while True:
+        yield path
+        i += 1
+        if max_ascent and max_ascent < i:
+            break
+        if path == top:
+            break
+        else:
+            path = path.parent
+
+
+def walk_down(path: Path, max_descent: int = None):
+    if max_descent == 0:
+        return
+
+    queue = []
+    for c in path.iterdir():
+        if c.is_dir():
+            yield c
+            queue.append(c)
+
+    for q in queue:
+        try:
+            yield from walk_down(q, max_descent=max_descent - 1 if max_descent else None)
+        except:
+            yield
+
+
+def find_ancestral_relatives(
+    target: Union[str, Path],
+    context: Path = Path.cwd(),
+    *,
+    from_parent_of_context: bool = True,
+    ancestral_levels: int = 2,
+    descendant_levels: int = 2,
+    top_level: Path = None,
+    return_parent_of_target: bool = True,
+    no_duplicates: bool = True,
+    terminate_first: bool = False,
+) -> List[Path]:
+    relatives = []
+
+    if top_level is None:
+        top_level = context.root
+
+    if from_parent_of_context:
+        context = context.parent
+
+    for p in walk_up(context, top_level, max_ascent=ancestral_levels):
+        for wd in walk_down(p, max_descent=descendant_levels):
+            if target in wd.parts[-ancestral_levels:]:
+                if return_parent_of_target:
+                    wd = wd.parent
+                relatives.append(wd)
+                if terminate_first:
+                    break
+        p /= target
+        if p.exists():
+            if return_parent_of_target:
+                p = p.parent
+            relatives.append(p)
+            if terminate_first:
+                break
+
+    if no_duplicates:
+        return list(set(relatives))
+
+    return relatives
+
+
+@passes_kws_to(find_ancestral_relatives)
+def find_nearest_ancestral_relative(*args, **kwargs) -> Optional[Path]:
+    kwargs.update(terminate_first=True)
+    result = find_ancestral_relatives(*args, **kwargs)
+    if result:
+        return result[0]
+
+
 def clean_sys_path() -> None:
     """
     Clean the sys.path for dead paths or duplicates
@@ -81,7 +166,6 @@ def ensure_in_sys_path(
 
     str_path = str(path)
     sys_path_snapshot = sys.path
-    inclusion_test = None
 
     if resolve:
         sys_path_snapshot = [Path(p).resolve() for p in sys_path_snapshot]
@@ -172,6 +256,10 @@ if __name__ == "__main__":
         s2 = sys.path
         print(s == s2, set(s2) - set(s), set(s) - set(s2), s2)
 
+    def asuhdsaud():
+        print(find_ancestral_relatives("queues"))
+
     # _main()
     # aisjdi()
-    iajsd()
+    # iajsd()
+    asuhdsaud()
